@@ -14,9 +14,10 @@
 void usage(){
   printf("usage: %s [options] <path> [<path>...]\n",opt_progname);
   printf(
-"  -V, --version    print version\n"
-"  -b, --bytes      output size in bytes rather than 512 byte blocks\n"
-"  -h, --help       display this message\n"
-"  -s, --summarize  display only a total for each argument\n"
+"  -V, --version     print version\n"
+"  -B, --block-size  set the block size\n"
+"  -b, --bytes       output size in bytes rather than 1024 byte blocks\n"
+"  -s, --summarize   display only a total for each argument\n"
+"  --help            display this message\n"
 "\n");
 }
